@@ -6,8 +6,8 @@ class User(object):
     name = Column(String(70))
 
 if __name__ == '__main__':
-    database = Database('sqlite://')
-    database.create_tables()
+    db = Database('sqlite://')
+    db.create_tables()
     
-    count = database.engine.execute('select count(name) from user').scalar()
+    count = db.engine.execute('select count(name) from user').scalar()
     print 'There are {0} users in total'.format(count)
